## 0.7.1-b3 - 2023-06-01

### Documentation

- [#866](https://github.com/edgarrmondragon/citric/issues/866) Add missing methods to RPC coverage page
- [#868](https://github.com/edgarrmondragon/citric/issues/868) Fix a couple of typos
